@@ -5,3 +5,5 @@ json = Moarjson('GlobalMoarJson')
 register = json.register
 dump = json.dump
 dumps = json.dumps
+load = json.load
+loads = json.loads
\ No newline at end of file
